**Email scraping software**

Parses emails and extracts Order number, Items and calculates unit prices and displays it in a excel file.


Supports:

    Amazon.ca 
    BestBuy.ca 
    EBGames.ca 
    Lego.ca
    Walmart.ca